C++ API reference
=================

This section documents the functions declared in
``Van_Rossum_Multiunit.hpp``.

----------

.. doxygenfunction:: d_exp_markage

.. doxygenfunction:: d_exp_markage_rect

